# Building the documentation

## Setup

Add the `docs` extra when installing `arkindex-base-worker`:

``` sh
# In a clone of the Git repository
pip install .[docs]
```

Build the documentation using `make html`.

## Writing documentation

This documentation uses [Sphinx](http://www.sphinx-doc.org/) and has been
configured to allow using both [CommonMark][1] and reStructuredText. There are
some special considerations when using Markdown, because its syntax is too
simple to normally allow using Sphinx features.

You can use [reStructuredText directives][2] in Markdown docs by using fenced
code blocks:

~~~ markdown
``` autoclass:: arkindex_worker.worker.base.BaseWorker
     :members:
```
~~~

For evaluating whole chunks of reST syntax and inserting them in your file,
you can use the `eval_rst` info string in your code blocks:

~~~ markdown
``` eval_rst
Here's a :cls:`link to a class <arkindex_worker.worker.base.BaseWorker>`

.. important:: This an important notice!
```
~~~

Another important consideration is the `Contents` section: a section with this
name should hold a list of links to other files, to be used as the main table
of contents:

``` markdown
## Contents

* [A file](file1)
* [Another file](file2)
```

This list will become the table of contents in the sidebar.

See `recommonmark`'s [AutoStructify documentation][3] for more information.

## Linting

This documentation is subject to linting using `doc8`, integrated into
`pre-commit`. You can run it locally by typing `pre-commit run`. You should use
`pre-commit install` to have the pre-commit hook run before each Git commit.

The linting rules that `doc8` applies can be found on [its documentation][4].

[1]: https://commonmark.org/help/
[2]: https://www.sphinx-doc.org/en/master/usage/restructuredtext/basics.html
[3]: https://recommonmark.readthedocs.io/en/latest/auto_structify.html
[4]: https://doc8.readthedocs.io/en/latest/readme.html#usage
